/*
                   Recycle Bin Recycled Object Statistics
 */

#ifndef EDV_RECBIN_STAT_H
#define EDV_RECBIN_STAT_H

#include <stdio.h>
#include <glib.h>
#include "edv_recycled_obj.h"


extern edv_recycled_object_struct *EDVRecBinObjectStat(
	const gchar *index_path,
	const guint index
);


#endif	/* EDV_RECBIN_STAT_H */
